@@ -200,6 +200,7 @@ CSoundFile::samplecount_t CSoundFile::ReadOneTick()
 {
 	const auto origMaxMixChannels = m_MixerSettings.m_nMaxMixChannels;
 	m_MixerSettings.m_nMaxMixChannels = 0;
+	ResetMixStat();
 	while(m_PlayState.m_nBufferCount)
 	{
 		auto framesToRender = std::min(m_PlayState.m_nBufferCount, samplecount_t(MIXBUFFERSIZE));
@@ -2387,6 +2388,9 @@ bool CSoundFile::ReadNote()
 					// In ST3, a sample rate of 8363 Hz is mapped to middle-C, which is 261.625 Hz in a tempered scale at A4 = 440.
 					// Hence, we have to translate our "sample rate" into pitch.
 					auto milliHertz = Util::muldivr_unsigned(freq, 261625, 8363 << FREQ_FRACBITS);
+#ifndef MODPLUG_TRACKER
+					milliHertz = Util::muldivr_unsigned(milliHertz, m_nFreqFactor, 65536);
+#endif  // !MODPLUG_TRACKER
 
 					const bool keyOff = chn.dwFlags[CHN_KEYOFF] || (chn.dwFlags[CHN_NOTEFADE] && chn.nFadeOutVol == 0);
 					if(!m_playBehaviour[kOPLNoteStopWith0Hz] || !keyOff)
